@@ -71,6 +71,8 @@ class random_timeout:
 class sleep_for:
     '''Sleep amount of time in minutes, hours or days and prints when it will continue'''
     def __init__(self, minutes=None, hours=None, days=None):
+        if seconds:
+            sleep(seconds)
         if minutes:
             til = datetime.now() + timedelta(minutes=minutes)
             til = til.strftime('%H:%M')
